@@ -22,18 +22,58 @@ from .resource import Resource, ResourceProxy
 from .role import Role
 from ..apps import MyadminConfig
 from framework.utils.log import logger
+from django.core.cache import cache
+from framework.utils import ObjectDict
+
 
 class UserManagerMixin(object):
     """用户管理者,扩展admin模型的方法
     """
+    _CACHE_ALLOW_MENU_KEY = '_cache_allow_menu'
+    _CACHE_MENU_MAP_KEY = '_cache_menu_map'
 
     def __init__(self, *args, **kwargs):
-        # self.resource = ResourceProxy(self)
         super(UserManagerMixin, self).__init__(*args, **kwargs)
-        self.__resource_map = {}
+        #self.resource = ResourceProxy(self)
+        self.__cache_resource_map = {}
         self.__cache_roles = None
+        self.allow_menu = None
+        self.menu_map = ObjectDict()
+        self.cache_allow_menu_key, self.cache_menu_map_key = self.get_cache_keys_for_id(self.id)
 
-    @property
+    def check_permission(self, key):
+        return self.allow_menu.get(key, None)
+
+    def get_menus(self):
+        user_menus = self.get_resource('menu').using('read')
+        return user_menus.all()
+
+    @classmethod
+    def get_cache_keys_for_id(cls, id):
+        return [f'{cls._CACHE_ALLOW_MENU_KEY}_{id}', f'{cls._CACHE_MENU_MAP_KEY}_{id}']
+
+    @classmethod
+    def clean_cache(cls, id):
+        cache.delete_many(cls.get_cache_keys_for_id(id))
+
+    def make_allow_map(self):
+        """生成权限"""
+        self.allow_menu = cache.get(self.cache_allow_menu_key, self.allow_menu)
+        self.menu_map = cache.get(self.cache_menu_map_key, self.menu_map)
+        if not self.allow_menu and not self.menu_map:
+            self.allow_menu = ObjectDict()
+            for m in self.get_menus():
+                menu_name = m.name
+                self.allow_menu[menu_name] = m
+                # 兼容旧的用中文权限检查方式
+                self.allow_menu[m.alias] = m
+
+                self.menu_map.setdefault(m.url_path, [])
+                self.menu_map[m.url_path].append(m)
+            cache.set(self.cache_allow_menu_key, self.allow_menu)
+            cache.set(self.cache_menu_map_key, self.menu_map)
+
+    @CacheAttribute
     def resource(self) -> Resource:
         return ResourceProxy(self)
 
@@ -50,7 +90,7 @@ class UserManagerMixin(object):
 
     @classmethod
     def get_user(cls, user_id):
-        """获取管理员
+        """获取用户
         """
         return cls.objects.filter(id=user_id).prefetch_related('role').first()
 
@@ -104,8 +144,8 @@ class UserManagerMixin(object):
         """获取自己的下属,除权限集合 如果是管理员这不能获取到
         """
         return User.objects.filter(
-                role__in=self.get_resource('role').exclude(type=Role.RoleType.PERMISSION)).prefetch_related(
-                'role').distinct()
+            role__in=self.get_resource('role').exclude(type=Role.RoleType.PERMISSION)).prefetch_related(
+            'role').distinct()
 
     def get_resource_attrs(self, resource_name, attr_name, input_list=None, allow_none=False):
         input_list = input_list or []
@@ -123,16 +163,16 @@ class UserManagerMixin(object):
     def set_resource(self, name, query_set):
         """设置资源,平台登录时就设置资源了
         """
-        self.__resource_map[name] = query_set
+        self.__cache_resource_map[name] = query_set
 
     def get_resource(self, name):
         """按资源名获取所属角色相应的资源
         """
-        _r = self.__resource_map.get(name, None)
+        _r = self.__cache_resource_map.get(name, None)
         if _r == None:
             _r = self._get_resource(name)
-        self.__resource_map[name] = _r
-        return self.__resource_map[name]
+        self.__cache_resource_map[name] = _r
+        return self.__cache_resource_map[name]
 
     def _get_resource(self, name):
         return Resource.get_model_resource(name).get_resource_queryset(self)
@@ -304,11 +344,7 @@ class User(BaseModel, AbstractBaseUser, UserManagerMixin):
     def user_info(self):
         user_info = None
         if self.id:
-            user_infos = self.userinfo_set.all()
-            if len(user_infos) >= 1:
-                user_info = user_infos[0]
-            else:
-                user_info, _ = self.userinfo_set.get_or_create()
+            user_info, _ = self.userinfo_set.get_or_create()
         return user_info
 
     @property
@@ -363,3 +399,17 @@ class UserOauth(BaseModel):
     class Meta:
         app_label = MyadminConfig.name
         # db_table = u'user_oauth'
+
+
+from django.db.models.signals import m2m_changed
+from django.dispatch import receiver
+
+
+@receiver(m2m_changed, sender=User.role.through, dispatch_uid="user_add_role")
+def user_add_role_ldap(sender, action, instance, reverse, model: User, pk_set, using, **kwargs):
+    if action in ['post_add', 'post_remove']:
+        if isinstance(instance, User):
+            UserManagerMixin.clean_cache(instance.id)
+        if isinstance(instance, Role):
+            for id in pk_set:
+                UserManagerMixin.clean_cache(id)
