@@ -8,9 +8,9 @@
 import datetime
 import time
 
-from django.http import HttpResponseRedirect
+from django.http import HttpResponseRedirect, HttpResponse
 from django.utils.translation import gettext_lazy as _
-
+from django.db import connection
 from framework.route import Route
 from framework.serializer import ParamsSerializer, s
 from framework.utils import TIMEFORMAT
@@ -36,7 +36,6 @@ def index(request: Request):
     now_timestamp = int(time.time())
     return Response(locals(), template_name='myadmin/index.html')
 
-
 class LoginError(RspError): pass
 
 
@@ -157,7 +156,7 @@ def phone_login(request):
     now = datetime.datetime.now()
     code = 0
     msg = ''
-    if request.is_post():
+    if request.is_post:
 
         try:
             phone = request.REQUEST.get('phone')
@@ -227,7 +226,7 @@ def register(request: Request, **kwargs):
     """
     管理员注册
     """
-    if request.is_post():
+    if request.is_post:
         params = RegisterAdminReqSerializer(request.data).params_data
 
         if request.session.get('verify', '') != params.verify:
