@@ -1,9 +1,10 @@
 # -*- coding: utf-8 -*-
-# @Time    : 2021-04-14 18:00
+# @Time    : 2021/9/30 16:59 
 # @Author  : xzr
-# @File    : conf
+# @File    : conf.py
 # @Software: PyCharm
 # @Contact : xzregg@gmail.com
 # @Desc    :
 
-from dynamic_settings.conf import *
+from django.conf import settings
+from dynamic_settings.conf import *
\ No newline at end of file
