@@ -7,13 +7,16 @@
 # @Desc    : 
 
 from rest_framework.renderers import JSONRenderer as RestJSONRenderer
-
+from django.conf import settings
 from .utils import MyJsonEncoder
 
 
 class JSONRenderer(RestJSONRenderer):
     encoder_class = MyJsonEncoder
 
+    def get_indent(self, accepted_media_type=None, renderer_context={}):
+        return 4 if settings.DEBUG else renderer_context.get('indent', None)
+
 
 class DebugRenderer(JSONRenderer):
     format = 'debug'
@@ -21,5 +24,5 @@ class DebugRenderer(JSONRenderer):
     media_type = 'text/html'
 
     def render(self, *args, **kwargs):
-        rsp = super().render( *args, **kwargs)
+        rsp = super().render(*args, **kwargs)
         return b'<body>%s</body>' % rsp
