@@ -3,12 +3,20 @@ import json
 
 from django.conf import settings
 from django.test import RequestFactory, TestCase
+from django.test.client import Client
 import pytest
 
 @pytest.fixture(scope='session')
 def django_db_setup():
     """使用现有数据库测试"""
     pass
+
+
+@pytest.mark.django_db
+def test_pytest_template():
+    pass
+
+
 class BaseTestCase(TestCase):
 
 
