@@ -30,8 +30,8 @@ default_supervisor_config = dict(
         stdout_events_enabled='false',
         loglevel='warn',
         stopsignal='TERM',
-#        killasgroup='true',
-#        stopasgroup='true'
+        #        killasgroup='true',
+        #        stopasgroup='true'
 )
 
 
@@ -72,12 +72,12 @@ def main():
     from config.daemon_service import DAEMON_SERVICE_MAP, INET_HTTP_SERVER_LISTEN, INET_HTTP_SERVER_PASSWORD, \
         INET_HTTP_SERVER_USERNAME
 
-    supervisord_cmd = 'supervisord -c %s' % supervisor_configfile
     cmd = supervisorctl_cmd = 'supervisorctl -c %s' % (supervisor_configfile)
     os.environ.setdefault('INET_HTTP_SERVER_LISTEN', INET_HTTP_SERVER_LISTEN)
     os.environ.setdefault('INET_HTTP_SERVER_USERNAME', INET_HTTP_SERVER_USERNAME)
     os.environ.setdefault('INET_HTTP_SERVER_PASSWORD', INET_HTTP_SERVER_PASSWORD)
     os.environ.setdefault('PROJECT_ROOT', pwd)
+    action = ''
 
     if len(sys.argv) > 1:
         action = sys.argv[1]
@@ -99,15 +99,26 @@ def main():
         argv_str = ' '.join(sys.argv[2:])
         cmd = '%s %s %s' % (supervisorctl_cmd, action, argv_str)
 
+    genrate_supervisor_conf(DAEMON_SERVICE_MAP, is_force=action in ['update', 'nodaemon'])
+
     is_supervisord_running = os.system(supervisorctl_cmd + ' pid') == 0
-    if not is_supervisord_running and action != 'shutdown':
-        print('supervisord not running,start now!\n%s' % supervisord_cmd)
-        os.system(supervisord_cmd)
-
-    genrate_supervisor_conf(DAEMON_SERVICE_MAP, is_force=action == 'update')
-
-    print(cmd)
-    os.system(cmd)
+    if not is_supervisord_running:
+        print('supervisord not running !\nusage: mysupervisorctl [start|nodaemon] ')
+        # -n/--nodaemon -- run in the foreground (same as 'nodaemon=true' in config file)
+        if action == 'nodaemon':
+            if not is_supervisord_running:
+                argv = ['supervisord', '-c', supervisor_configfile, '-n']
+                print(f'exec {" ".join(argv)} ')
+                os.execvp('supervisord', argv)
+            return
+        if action == 'start':
+            supervisord_cmd = 'supervisord -c %s' % supervisor_configfile
+            print(supervisord_cmd)
+            os.system(supervisord_cmd)
+            return
+        sys.exit(1)
+    else:
+        os.system(cmd)
 
 
 if __name__ == '__main__':
