@@ -20,10 +20,17 @@ DEBUG = True
 SECRET_KEY = '%s'
 BASE_DIR = os.path.dirname(os.path.abspath(__file__))
 
-APPS = ['djmyframework']
+APPS = ['djmyframework','myadmin', 'analysis', 'celery_task', 'log_def', 'upload', 'sync_model', 'ws_gateway','dynamic_settings']
+
 APPS_ROOT = os.path.join(BASE_DIR, 'apps')
 
 from djmyframework.settings import *
+LANGUAGES = (
+        ('de', _('German')),
+        ('en', _('English')),
+        ('zh-hans', _('简体')),
+        ('zh-hant', _('繁体')),
+)
 
 PROJECT_ROOT = BASE_DIR
 
