@@ -15,7 +15,7 @@ pymysql.install_as_MySQLdb()
 import sys
 import os
 import jinja2
-
+import daphne.server
 from django.utils.translation import gettext_lazy as _
 from objectdict import sort_set_list
 from django.conf import settings
@@ -58,14 +58,14 @@ AUTH_USER_MODEL = 'myadmin.User'
 
 APPS = settings.APPS or APPS
 
-VIEWS_DIR = 'views'
+VIEWS_DIR = ['views', 'controller']
 ROUTE_PREFIX = ''
 ROUTE_APP_PREFIX_MAP = {}
 
 INSTALLED_APPS = ['djorm_pool',
                   'framework',
                   'channels',
-                  # 'django.contrib.admin',
+                  #'django.contrib.admin',
                   'django.contrib.auth',
                   'django.contrib.contenttypes',
                   'django.contrib.sessions',
@@ -145,6 +145,7 @@ MIDDLEWARE = [
     # 'django.middleware.clickjacking.XFrameOptionsMiddleware',
     'django_user_agents.middleware.UserAgentMiddleware',
     'framework.middleware.BaseMiddleware',
+    'framework.perf_orm_select.PerfOrmSelectMiddleware',
     'myadmin.middleware.AuthMiddleware'
 ]
 
